==> openjpa-parent-2.4.3-source-release.zip: openjpa-parent-2.4.3/openjpa-lib/src/main/java/org/apache/openjpa/lib/util/ParseException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.openjpa.lib.util;

import org.apache.commons.lang.exception.NestableRuntimeException;

/**
 * Exception type for parse errors.
 *
 * @author Abe White
 * @since 0.4.0
 */
public class ParseException extends NestableRuntimeException {

    public ParseException() {
    }

    public ParseException(String msg) {
        super(msg);
    }

    public ParseException(Localizer.Message msg) {
        super(msg.getMessage());
    }

    public ParseException(Throwable cause) {
        super(cause);
    }

    public ParseException(String msg, Throwable cause) {
        super(msg, cause);
    }

    public ParseException(Localizer.Message msg, Throwable cause) {
        super(msg.getMessage(), cause);
    }
}

==> openjpa-parent-4.1.1-source-release.zip: openjpa-parent-4.1.1/openjpa-lib/src/main/java/org/apache/openjpa/lib/util/ParseException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openjpa.lib.util;


/**
 * Exception type for parse errors.
 *
 * @author Abe White
 * @since 0.4.0
 */
public class ParseException extends RuntimeException {

    
    private static final long serialVersionUID = 1L;

    public ParseException() {
    }

    public ParseException(String msg) {
        super(msg);
    }

    public ParseException(Localizer.Message msg) {
        super(msg.getMessage());
    }

    public ParseException(Throwable cause) {
        super(cause);
    }

    public ParseException(String msg, Throwable cause) {
        super(msg, cause);
    }

    public ParseException(Localizer.Message msg, Throwable cause) {
        super(msg.getMessage(), cause);
    }
}
